use strict;

use Test;
use vars qw($loaded $autoseed1 $autoseed2 $autoseed3 $autoseed4);
use Benchmark qw(timediff timestr);

BEGIN { plan tests => 8 }
END   { print "not ok 1\n" unless $loaded }

# Make sure that automatic seeds generated close in time are different.

use Math::Random::MT::Perl qw(srand rand);
ok($loaded = 1);
# Generate a series of 3 random numbers using an autogenerated seed
ok($autoseed1 = srand());
ok($autoseed2 = srand());
ok($autoseed3 = srand());
ok($autoseed4 = srand());
ok($autoseed1 != $autoseed2);
ok($autoseed2 != $autoseed3);
ok($autoseed3 != $autoseed4);
